pub struct DHPrivateKey(/* private fields */);Expand description
A ristretto255 scalar in $\mathbb{Z}_\ell$.
This can be instantiated only by validating decode or by wide reduction, so it is always canonical.
Implementations
Sourceimpl DHPrivateKey
impl DHPrivateKey
Sourcepub fn decode(bytes: [u8; 32]) -> Result<Self, Error>
pub fn decode(bytes: [u8; 32]) -> Result<Self, Error>
Decode a scalar from bytes, validating it is a canonical element of $\mathbb{Z}_\ell$.
Sourcepub fn public_key(&self) -> DHPublicKey
pub fn public_key(&self) -> DHPublicKey
Derive the public key $[sk] B$.