pub struct DHPublicKey(/* private fields */);Expand description
A ristretto255 group element.
Security
This can be instantiated only by decoding, by the element derivation function, or by a group operation, so it is always a valid ristretto255 element. The element is held decompressed, so repeated operations on the same key do not repeat point decompression.
Implementations
Sourceimpl DHPublicKey
impl DHPublicKey
Sourcepub fn decode(bytes: [u8; 32]) -> Result<Self, Error>
pub fn decode(bytes: [u8; 32]) -> Result<Self, Error>
Decode a group element from its 32 byte encoding, validating that it is a real ristretto255 element.
This must be used for any untrusted bytes (wire or storage) such that an invalid element cannot be instantiated.
Sourcepub fn into_bytes(self) -> [u8; 32]
pub fn into_bytes(self) -> [u8; 32]
The canonical 32-byte encoding of this element.